
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2017-12-14T20:57:29-0600",
 "dirty": false,
 "error": null,
 "full-revisionid": "a14d1c67b010e85b8943675ebefa811a4a41b777",
 "version": "3.1.4"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
